import { defineStore } from 'pinia'
import { getUser } from '@/api/user'
import { removeToken } from '@/utils/token'

export const useUserStore = defineStore('user', {
  state() {
    return {
      userInfo: {}
    }
  },
  getters: {
    userInfoMsg() {
      return this.userInfo
    }
  },
  actions: {
    async getUserInfo() {
      try {
        const res = await getUser()
        if (res.code === 0) {
          this.userInfo = res.data
          return Promise.resolve(res.msg)
        } else {
          return Promise.reject(res.msg)
        }
      } catch (error) {
        console.error(error)
        return Promise.reject(error.msg)
      }
    },
    logout() {
      removeToken()
      this.userInfo = {}
    },
    setUserInfo(userInfo = {}) {
      this.userInfo = { ...this.userInfo, ...userInfo }
    }
  }
})
